@@ -12,7 +12,7 @@ CASES = [
     ("press", {"keys": ["ctrl", "c"]}),
     ("keydown", {"keys": ["shift"]}),
     ("keyup", {"keys": ["shift"]}),
-    ("type", {"text": "hello"}),
+    ("write", {"text": "hello"}),
     ("scroll", {"x": 10, "y": 10, "scroll_y": 20}),  # Added required x,y coordinates
     # Skip move test - it has Field parameter handling issues when called directly
     # ("move", {"x": 5, "y": 5}),  # x,y are for absolute positioning
